function plot_separate(path,die,device,line1,line2,line3)
%Plot-script for plotting physical DC measurments along with tt, ss and ff
%simulations in the same plot
%Example of use: plot_separate('d:\temp','die2','nmos1',20,14,8)
%Parameter "path" is the directory at which you are at present.
%Parameter "line" indicates which measurement/simulation you want to plot (must be a
%positive number between 1 and 20).
%Parameters "die" and "device" must be chosen according to the dies and
%devices available in the directories.
%Solid line = physical measurement
%Dotted line = simulated tt
%Dashdot line = simulated ss
%Dashed line = simulated ff
%Big black dots = simulated ssa

%notice that Matlab treats starting point for any tabular matrix as [1,1], not [0,0]
%plot(x,y)
%matrix(row,column)

%Remember also that you will have 4 warnings per run, due to taking the
%logarithm of zero for the four gateleak-simulations (because Ig = 0 when
%Vgs=0 for the gateleak-simulations). Just ignore this.

%LINE NUMBERING (used for the choice of both Vds and Vgs)
%0.00V => not applicable (besides, usually of no interest)
%0.05V => linex=1
%0.10V => linex=2
%0.15V => linex=3
%0.20V => linex=4
%0.25V => linex=5
%0.30V => linex=6
%0.35V => linex=7
%0.40V => linex=8
%0.45V => linex=9
%0.50V => linex=10
%0.55V => linex=11
%0.60V => linex=12
%0.65V => linex=13
%0.70V => linex=14
%0.75V => linex=15
%0.80V => linex=16
%0.85V => linex=17
%0.90V => linex=18
%0.95V => linex=19
%1.00V => linex=20


%open data files for physical measurements
data_fine0 = xlsread([path,'\Physical\Processed data\',die,'\',device,'\id-fine-vb0']);
data_fine1 = xlsread([path,'\Physical\Processed data\',die,'\',device,'\id-fine-vb1']);
data_fine2 = xlsread([path,'\Physical\Processed data\',die,'\',device,'\id-fine-vb2']);
data_subvt = xlsread([path,'\Physical\Processed data\',die,'\',device,'\subvt']);
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    data_gateleak = xlsread([path,'\Physical\Processed data\',die,'\nmos0\ig-vg']);
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    data_gateleak = xlsread([path,'\Physical\Processed data\',die,'\pmos0\ig-vg']);
end

%open data files from simulations
data_sim_tt = csvread([path,'\Simulated\tt\',device,'\simdata.txt'],1,0); %Notice that headings are not imported
data_sim_ss = csvread([path,'\Simulated\ss\',device,'\simdata.txt'],1,0);
data_sim_ff = csvread([path,'\Simulated\ff\',device,'\simdata.txt'],1,0);
data_sim_ssa = csvread([path,'\Simulated\ssa\',device,'\simdata.txt'],1,0);


start = 7; %6 minimum value is 0
interval = 6; %3 mimimum value is 1


%if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )

%elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )




%##########################################################################
%######################      vds-id       #################################
%##########################################################################


%#####################
%####### line1 #######
%#####################

%measured
figure(1)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for column=5*start:5*interval:100
    column=5*line1;
        for row=0:1:20
            xaxis(1+row) = data_fine0(1+row,4+column);
            yaxis(1+row) = data_fine0(1+row,3+column);
        end
        plot(xaxis,yaxis,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for column=5*start:5*interval:100
    column=5*line1;
        for row=0:1:20
            xaxis(1+row) = data_fine0(1+row,2+column);
            yaxis(1+row) = data_fine0(1+row,1+column);
        end
        plot(xaxis,yaxis,'k-')
end
clear xaxis
clear yaxis






%simulated tt
figure(1)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_tt(1+row,7+column);
            yaxis(1+column/21) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_tt(1+row,7+column);
            yaxis(1+column/21) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis





%simulated ss
figure(1)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ss(1+row,7+column);
            yaxis(1+column/21) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ss(1+row,7+column);
            yaxis(1+column/21) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis




%simulated ff
figure(1)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ff(1+row,7+column);
            yaxis(1+column/21) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ff(1+row,7+column);
            yaxis(1+column/21) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis





%simulated ssa
figure(1)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
            yaxis(1+column/21) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
            yaxis(1+column/21) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis




xlabel('V_{DS} [V]');
ylabel('I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{DS} - I_{D}, ','V_{GS}=1V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{DS} - I_{D}, ','V_{GS}=-1V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line2 #######
%#####################

%measured
figure(2)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for column=5*start:5*interval:100
    column=5*line2;
        for row=0:1:20
            xaxis(1+row) = data_fine0(1+row,4+column);
            yaxis(1+row) = data_fine0(1+row,3+column);
        end
        plot(xaxis,yaxis,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for column=5*start:5*interval:100
    column=5*line2;
        for row=0:1:20
            xaxis(1+row) = data_fine0(1+row,2+column);
            yaxis(1+row) = data_fine0(1+row,1+column);
        end
        plot(xaxis,yaxis,'k-')
end
clear xaxis
clear yaxis






%simulated tt
figure(2)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_tt(1+row,7+column);
            yaxis(1+column/21) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_tt(1+row,7+column);
            yaxis(1+column/21) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis





%simulated ss
figure(2)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ss(1+row,7+column);
            yaxis(1+column/21) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ss(1+row,7+column);
            yaxis(1+column/21) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis




%simulated ff
figure(2)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ff(1+row,7+column);
            yaxis(1+column/21) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ff(1+row,7+column);
            yaxis(1+column/21) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis





%simulated ssa
figure(2)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
            yaxis(1+column/21) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
            yaxis(1+column/21) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis




xlabel('V_{DS} [V]');
ylabel('I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{DS} - I_{D}, ','V_{GS}=0.7V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{DS} - I_{D}, ','V_{GS}=-0.7V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line3 #######
%#####################

%measured
figure(3)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for column=5*start:5*interval:100
    column=5*line3;
        for row=0:1:20
            xaxis(1+row) = data_fine0(1+row,4+column);
            yaxis(1+row) = data_fine0(1+row,3+column);
        end
        plot(xaxis,yaxis,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for column=5*start:5*interval:100
    column=5*line3;
        for row=0:1:20
            xaxis(1+row) = data_fine0(1+row,2+column);
            yaxis(1+row) = data_fine0(1+row,1+column);
        end
        plot(xaxis,yaxis,'k-')
end
clear xaxis
clear yaxis






%simulated tt
figure(3)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_tt(1+row,7+column);
            yaxis(1+column/21) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_tt(1+row,7+column);
            yaxis(1+column/21) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis





%simulated ss
figure(3)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ss(1+row,7+column);
            yaxis(1+column/21) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ss(1+row,7+column);
            yaxis(1+column/21) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis




%simulated ff
figure(3)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ff(1+row,7+column);
            yaxis(1+column/21) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ff(1+row,7+column);
            yaxis(1+column/21) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis





%simulated ssa
figure(3)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
            yaxis(1+column/21) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
            yaxis(1+column/21) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis




xlabel('V_{DS} [V]');
ylabel('I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{DS} - I_{D}, ','V_{GS}=0.4V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{DS} - I_{D}, ','V_{GS}=-0.4V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;






%##########################################################################
%######################        gds        #################################
%##########################################################################


%#####################
%####### line1 #######
%#####################

%measured
figure(4)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for column=5*start:5*interval:100
    column=5*line1;
        for row=0:1:20
            if row==0
                xaxis(1+row) = NaN;
                gds(1+row) = NaN;
                ;
            else
                xaxis(1+row) = data_fine0(1+row,4+column);
                gds(1+row) = log10( (data_fine0(1+row,3+column)-data_fine0(1+row-1,3+column))/(data_fine0(1+row,4+column)-data_fine0(1+row-1,4+column)) );
            end
        end
        plot(xaxis,gds,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for column=5*start:5*interval:100
    column=5*line1;
        for row=0:1:20
            if row==0
                xaxis(1+row) = NaN;
                gds(1+row) = NaN;
                ;
            else
                xaxis(1+row) = data_fine0(1+row,2+column);
                gds(1+row) = log10( (data_fine0(1+row,1+column)-data_fine0(1+row-1,1+column))/(data_fine0(1+row,2+column)-data_fine0(1+row-1,2+column)) );
            end
        end
        plot(xaxis,gds,'k-')
end
clear xaxis
clear yaxis





%simulated tt
figure(4)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_tt(1+row,7+column); %these two line1s _calculates_ gds manually
                yaxis(1+column/21) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row,2+column-21))/(data_sim_tt(1+row,7+column)-data_sim_tt(1+row,7+column-21)) );
%                xaxis2(1+column/21) = data_sim_tt(1+row,7+column); %these two line1s uses the eldo-calculated values of gds directly
%                yaxis2(1+column/21) = data_sim_tt(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k:')
%        plot(xaxis2,yaxis2,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_tt(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row,2+column-21))/(data_sim_tt(1+row,7+column)-data_sim_tt(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_tt(1+row,7+column);
%                yaxis(1+column/21) = data_sim_tt(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis





%simulated ss
figure(4)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row,2+column-21))/(data_sim_ss(1+row,7+column)-data_sim_ss(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ss(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row,2+column-21))/(data_sim_ss(1+row,7+column)-data_sim_ss(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ss(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis




%simulated ff
figure(4)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row,2+column-21))/(data_sim_ff(1+row,7+column)-data_sim_ff(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ff(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row,2+column-21))/(data_sim_ff(1+row,7+column)-data_sim_ff(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ff(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis





%simulated ssa
figure(4)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row,2+column-21))/(data_sim_ssa(1+row,7+column)-data_sim_ssa(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ssa(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line1;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row,2+column-21))/(data_sim_ssa(1+row,7+column)-data_sim_ssa(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ssa(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis




xlabel('V_{DS}');
ylabel('log_{10} g_{ds} [S]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{DS} - g_{ds}, ','V_{GS}=1V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{DS} - g_{ds}, ','V_{GS}=-1V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line2 #######
%#####################

%measured
figure(5)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for column=5*start:5*interval:100
    column=5*line2;
        for row=0:1:20
            if row==0
                xaxis(1+row) = NaN;
                gds(1+row) = NaN;
                ;
            else
                xaxis(1+row) = data_fine0(1+row,4+column);
                gds(1+row) = log10( (data_fine0(1+row,3+column)-data_fine0(1+row-1,3+column))/(data_fine0(1+row,4+column)-data_fine0(1+row-1,4+column)) );
            end
        end
        plot(xaxis,gds,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for column=5*start:5*interval:100
    column=5*line2;
        for row=0:1:20
            if row==0
                xaxis(1+row) = NaN;
                gds(1+row) = NaN;
                ;
            else
                xaxis(1+row) = data_fine0(1+row,2+column);
                gds(1+row) = log10( (data_fine0(1+row,1+column)-data_fine0(1+row-1,1+column))/(data_fine0(1+row,2+column)-data_fine0(1+row-1,2+column)) );
            end
        end
        plot(xaxis,gds,'k-')
end
clear xaxis
clear yaxis





%simulated tt
figure(5)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_tt(1+row,7+column); %these two line2s _calculates_ gds manually
                yaxis(1+column/21) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row,2+column-21))/(data_sim_tt(1+row,7+column)-data_sim_tt(1+row,7+column-21)) );
%                xaxis2(1+column/21) = data_sim_tt(1+row,7+column); %these two line2s uses the eldo-calculated values of gds directly
%                yaxis2(1+column/21) = data_sim_tt(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k:')
%        plot(xaxis2,yaxis2,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_tt(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row,2+column-21))/(data_sim_tt(1+row,7+column)-data_sim_tt(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_tt(1+row,7+column);
%                yaxis(1+column/21) = data_sim_tt(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis





%simulated ss
figure(5)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row,2+column-21))/(data_sim_ss(1+row,7+column)-data_sim_ss(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ss(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row,2+column-21))/(data_sim_ss(1+row,7+column)-data_sim_ss(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ss(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis




%simulated ff
figure(5)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row,2+column-21))/(data_sim_ff(1+row,7+column)-data_sim_ff(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ff(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row,2+column-21))/(data_sim_ff(1+row,7+column)-data_sim_ff(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ff(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis





%simulated ssa
figure(5)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row,2+column-21))/(data_sim_ssa(1+row,7+column)-data_sim_ssa(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ssa(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line2;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row,2+column-21))/(data_sim_ssa(1+row,7+column)-data_sim_ssa(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ssa(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis




xlabel('V_{DS}');
ylabel('log_{10} g_{ds} [S]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{DS} - g_{ds}, ','V_{GS}=0.7V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{DS} - g_{ds}, ','V_{GS}=-0.7V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line3 #######
%#####################

%measured
figure(6)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for column=5*start:5*interval:100
    column=5*line3;
        for row=0:1:20
            if row==0
                xaxis(1+row) = NaN;
                gds(1+row) = NaN;
                ;
            else
                xaxis(1+row) = data_fine0(1+row,4+column);
                gds(1+row) = log10( (data_fine0(1+row,3+column)-data_fine0(1+row-1,3+column))/(data_fine0(1+row,4+column)-data_fine0(1+row-1,4+column)) );
            end
        end
        plot(xaxis,gds,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for column=5*start:5*interval:100
    column=5*line3;
        for row=0:1:20
            if row==0
                xaxis(1+row) = NaN;
                gds(1+row) = NaN;
                ;
            else
                xaxis(1+row) = data_fine0(1+row,2+column);
                gds(1+row) = log10( (data_fine0(1+row,1+column)-data_fine0(1+row-1,1+column))/(data_fine0(1+row,2+column)-data_fine0(1+row-1,2+column)) );
            end
        end
        plot(xaxis,gds,'k-')
end
clear xaxis
clear yaxis





%simulated tt
figure(6)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_tt(1+row,7+column); %these two line3s _calculates_ gds manually
                yaxis(1+column/21) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row,2+column-21))/(data_sim_tt(1+row,7+column)-data_sim_tt(1+row,7+column-21)) );
%                xaxis2(1+column/21) = data_sim_tt(1+row,7+column); %these two line3s uses the eldo-calculated values of gds directly
%                yaxis2(1+column/21) = data_sim_tt(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k:')
%        plot(xaxis2,yaxis2,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_tt(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row,2+column-21))/(data_sim_tt(1+row,7+column)-data_sim_tt(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_tt(1+row,7+column);
%                yaxis(1+column/21) = data_sim_tt(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis





%simulated ss
figure(6)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row,2+column-21))/(data_sim_ss(1+row,7+column)-data_sim_ss(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ss(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row,2+column-21))/(data_sim_ss(1+row,7+column)-data_sim_ss(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ss(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ss(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis




%simulated ff
figure(6)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row,2+column-21))/(data_sim_ff(1+row,7+column)-data_sim_ff(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ff(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row,2+column-21))/(data_sim_ff(1+row,7+column)-data_sim_ff(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ff(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ff(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis





%simulated ssa
figure(6)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for row=20+start:1*interval:40
    row=20+line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                gds(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row,2+column-21))/(data_sim_ssa(1+row,7+column)-data_sim_ssa(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ssa(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for row=20+start:-1*interval:0
    row=20-line3;
        for column=21*0:21:21*20
            if column==21*0
                xaxis(1+column/21) = NaN;
                yaxis(1+column/21) = NaN;
            else
                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
                yaxis(1+column/21) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row,2+column-21))/(data_sim_ssa(1+row,7+column)-data_sim_ssa(1+row,7+column-21)) );
%                xaxis(1+column/21) = data_sim_ssa(1+row,7+column);
%                yaxis(1+column/21) = data_sim_ssa(1+row,6+column);
            end
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis




xlabel('V_{DS}');
ylabel('log_{10} g_{ds} [S]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{DS} - g_{ds}, ','V_{GS}=0.4V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{DS} - g_{ds}, ','V_{GS}=-0.4V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%##########################################################################
%######################       vgs-id      #################################
%##########################################################################

%#####################
%####### line1 #######
%#####################

%measured
figure(7)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=1*start:1*interval:20
    row=line1;
        for column=0:5:100
            xaxis(1+column/5) = data_fine0(1+row,5+column);
            yaxis(1+column/5) = data_fine0(1+row,3+column);
        end
        plot(xaxis,yaxis,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=1*start:1*interval:20
    row=line1;
        for column=0:5:100
            xaxis(1+column/5) = data_fine0(1+row,3+column);
            yaxis(1+column/5) = data_fine0(1+row,1+column);
        end
        plot(xaxis,yaxis,'k-')
end
clear xaxis
clear yaxis





%simulated tt
figure(7)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_tt(1+row,8+column);
            yaxis(1+row-20) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis






%simulated ss
figure(7)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ss(1+row,8+column);
            yaxis(1+row-20) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis







%simulated ff
figure(7)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ff(1+row,8+column);
            yaxis(1+row-20) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis






%simulated ssa
figure(7)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-20) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis





xlabel('V_{GS} [V]');
ylabel('I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=1V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-1V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line2 #######
%#####################

%measured
figure(8)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=1*start:1*interval:20
    row=line2;
        for column=0:5:100
            xaxis(1+column/5) = data_fine0(1+row,5+column);
            yaxis(1+column/5) = data_fine0(1+row,3+column);
        end
        plot(xaxis,yaxis,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=1*start:1*interval:20
    row=line2;
        for column=0:5:100
            xaxis(1+column/5) = data_fine0(1+row,3+column);
            yaxis(1+column/5) = data_fine0(1+row,1+column);
        end
        plot(xaxis,yaxis,'k-')
end
clear xaxis
clear yaxis





%simulated tt
figure(8)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_tt(1+row,8+column);
            yaxis(1+row-20) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis






%simulated ss
figure(8)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ss(1+row,8+column);
            yaxis(1+row-20) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis







%simulated ff
figure(8)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ff(1+row,8+column);
            yaxis(1+row-20) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis






%simulated ssa
figure(8)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-20) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis





xlabel('V_{GS} [V]');
ylabel('I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=0.7V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-0.7V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line3 #######
%#####################

%measured
figure(9)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=1*start:1*interval:20
    row=line3;
        for column=0:5:100
            xaxis(1+column/5) = data_fine0(1+row,5+column);
            yaxis(1+column/5) = data_fine0(1+row,3+column);
        end
        plot(xaxis,yaxis,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=1*start:1*interval:20
    row=line3;
        for column=0:5:100
            xaxis(1+column/5) = data_fine0(1+row,3+column);
            yaxis(1+column/5) = data_fine0(1+row,1+column);
        end
        plot(xaxis,yaxis,'k-')
end
clear xaxis
clear yaxis





%simulated tt
figure(9)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_tt(1+row,8+column);
            yaxis(1+row-20) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = data_sim_tt(1+row,2+column);
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis
clear yaxis






%simulated ss
figure(9)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ss(1+row,8+column);
            yaxis(1+row-20) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = data_sim_ss(1+row,2+column);
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis
clear yaxis







%simulated ff
figure(9)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ff(1+row,8+column);
            yaxis(1+row-20) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = data_sim_ff(1+row,2+column);
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis
clear yaxis






%simulated ssa
figure(9)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-20) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = data_sim_ssa(1+row,2+column);
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis
clear yaxis





xlabel('V_{GS} [V]');
ylabel('I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=0.4V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-0.4V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%##########################################################################
%######################          gm       #################################
%##########################################################################


%#####################
%####### line1 #######
%#####################

%measured
figure(10)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=1*start:1*interval:20
    row=line1;
        for column=0:5:100
            if column==0
                xaxis(1+column/5) = NaN;
                gm(1+column/5) = NaN;
                ;
            else
                xaxis(1+column/5) = data_fine0(1+row,5+column);
                gm(1+column/5) = log10( (data_fine0(1+row,3+column)-data_fine0(1+row,3+column-5))/(data_fine0(1+row,5+column)-data_fine0(1+row,5+column-5)) );
            end
        end
        plot(xaxis,gm,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=1*start:1*interval:20
    row=line1;
        for column=0:5:100
            if column==0
                xaxis(1+column/5) = NaN;
                gm(1+column/5) = NaN;
                ;
            else
                xaxis(1+column/5) = data_fine0(1+row,3+column);
                gm(1+column/5) = log10( (data_fine0(1+row,1+column)-data_fine0(1+row,1+column-5))/(data_fine0(1+row,3+column)-data_fine0(1+row,3+column-5)) );
            end
        end
        plot(xaxis,gm,'k-')
end
clear xaxis;
clear yaxis;





%simulated tt
figure(10)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_tt(1+row,8+column); %these two line1s _calculates_ gm manually
                yaxis(1+row-20) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row-1,2+column))/(data_sim_tt(1+row,8+column)-data_sim_tt(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_tt(1+row,8+column); %these two line1s uses the eldo-calculated values of gm directly
%                yaxis(1+row-20) = data_sim_tt(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_tt(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row+1,2+column))/(data_sim_tt(1+row,8+column)-data_sim_tt(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_tt(1+row,8+column);
%                yaxis(1+row) = data_sim_tt(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;






%simulated ss
figure(10)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ss(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row-1,2+column))/(data_sim_ss(1+row,8+column)-data_sim_ss(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ss(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ss(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ss(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row+1,2+column))/(data_sim_ss(1+row,8+column)-data_sim_ss(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ss(1+row,8+column);
%                yaxis(1+row) = data_sim_ss(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;






%simulated ff
figure(10)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ff(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row-1,2+column))/(data_sim_ff(1+row,8+column)-data_sim_ff(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ff(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ff(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ff(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row+1,2+column))/(data_sim_ff(1+row,8+column)-data_sim_ff(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ff(1+row,8+column);
%                yaxis(1+row) = data_sim_ff(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;






%simulated ssa
figure(10)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row-1,2+column))/(data_sim_ssa(1+row,8+column)-data_sim_ssa(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ssa(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line1;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ssa(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row+1,2+column))/(data_sim_ssa(1+row,8+column)-data_sim_ssa(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ssa(1+row,8+column);
%                yaxis(1+row) = data_sim_ssa(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;




xlabel('V_{GS}');
ylabel('log_{10} g_{m} [S]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{GS} - g_{m}, ','V_{DS}=1V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{GS} - g_{m}, ','V_{DS}=-1V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%#####################
%####### line2 #######
%#####################

%measured
figure(11)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=1*start:1*interval:20
    row=line2;
        for column=0:5:100
            if column==0
                xaxis(1+column/5) = NaN;
                gm(1+column/5) = NaN;
                ;
            else
                xaxis(1+column/5) = data_fine0(1+row,5+column);
                gm(1+column/5) = log10( (data_fine0(1+row,3+column)-data_fine0(1+row,3+column-5))/(data_fine0(1+row,5+column)-data_fine0(1+row,5+column-5)) );
            end
        end
        plot(xaxis,gm,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=1*start:1*interval:20
    row=line2;
        for column=0:5:100
            if column==0
                xaxis(1+column/5) = NaN;
                gm(1+column/5) = NaN;
                ;
            else
                xaxis(1+column/5) = data_fine0(1+row,3+column);
                gm(1+column/5) = log10( (data_fine0(1+row,1+column)-data_fine0(1+row,1+column-5))/(data_fine0(1+row,3+column)-data_fine0(1+row,3+column-5)) );
            end
        end
        plot(xaxis,gm,'k-')
end
clear xaxis;
clear yaxis;





%simulated tt
figure(11)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_tt(1+row,8+column); %these two line2s _calculates_ gm manually
                yaxis(1+row-20) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row-1,2+column))/(data_sim_tt(1+row,8+column)-data_sim_tt(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_tt(1+row,8+column); %these two line2s uses the eldo-calculated values of gm directly
%                yaxis(1+row-20) = data_sim_tt(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_tt(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row+1,2+column))/(data_sim_tt(1+row,8+column)-data_sim_tt(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_tt(1+row,8+column);
%                yaxis(1+row) = data_sim_tt(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;






%simulated ss
figure(11)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ss(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row-1,2+column))/(data_sim_ss(1+row,8+column)-data_sim_ss(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ss(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ss(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ss(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row+1,2+column))/(data_sim_ss(1+row,8+column)-data_sim_ss(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ss(1+row,8+column);
%                yaxis(1+row) = data_sim_ss(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;






%simulated ff
figure(11)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ff(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row-1,2+column))/(data_sim_ff(1+row,8+column)-data_sim_ff(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ff(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ff(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ff(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row+1,2+column))/(data_sim_ff(1+row,8+column)-data_sim_ff(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ff(1+row,8+column);
%                yaxis(1+row) = data_sim_ff(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;






%simulated ssa
figure(11)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row-1,2+column))/(data_sim_ssa(1+row,8+column)-data_sim_ssa(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ssa(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line2;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ssa(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row+1,2+column))/(data_sim_ssa(1+row,8+column)-data_sim_ssa(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ssa(1+row,8+column);
%                yaxis(1+row) = data_sim_ssa(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;




xlabel('V_{GS}');
ylabel('log_{10} g_{m} [S]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{GS} - g_{m}, ','V_{DS}=0.7V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{GS} - g_{m}, ','V_{DS}=-0.7V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;



%#####################
%####### line3 #######
%#####################

%measured
figure(12)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=1*start:1*interval:20
    row=line3;
        for column=0:5:100
            if column==0
                xaxis(1+column/5) = NaN;
                gm(1+column/5) = NaN;
                ;
            else
                xaxis(1+column/5) = data_fine0(1+row,5+column);
                gm(1+column/5) = log10( (data_fine0(1+row,3+column)-data_fine0(1+row,3+column-5))/(data_fine0(1+row,5+column)-data_fine0(1+row,5+column-5)) );
            end
        end
        plot(xaxis,gm,'k-')
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=1*start:1*interval:20
    row=line3;
        for column=0:5:100
            if column==0
                xaxis(1+column/5) = NaN;
                gm(1+column/5) = NaN;
                ;
            else
                xaxis(1+column/5) = data_fine0(1+row,3+column);
                gm(1+column/5) = log10( (data_fine0(1+row,1+column)-data_fine0(1+row,1+column-5))/(data_fine0(1+row,3+column)-data_fine0(1+row,3+column-5)) );
            end
        end
        plot(xaxis,gm,'k-')
end
clear xaxis;
clear yaxis;





%simulated tt
figure(12)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_tt(1+row,8+column); %these two line3s _calculates_ gm manually
                yaxis(1+row-20) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row-1,2+column))/(data_sim_tt(1+row,8+column)-data_sim_tt(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_tt(1+row,8+column); %these two line3s uses the eldo-calculated values of gm directly
%                yaxis(1+row-20) = data_sim_tt(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_tt(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_tt(1+row,2+column)-data_sim_tt(1+row+1,2+column))/(data_sim_tt(1+row,8+column)-data_sim_tt(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_tt(1+row,8+column);
%                yaxis(1+row) = data_sim_tt(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;






%simulated ss
figure(12)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ss(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row-1,2+column))/(data_sim_ss(1+row,8+column)-data_sim_ss(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ss(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ss(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ss(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ss(1+row,2+column)-data_sim_ss(1+row+1,2+column))/(data_sim_ss(1+row,8+column)-data_sim_ss(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ss(1+row,8+column);
%                yaxis(1+row) = data_sim_ss(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;






%simulated ff
figure(12)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ff(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row-1,2+column))/(data_sim_ff(1+row,8+column)-data_sim_ff(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ff(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ff(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ff(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ff(1+row,2+column)-data_sim_ff(1+row+1,2+column))/(data_sim_ff(1+row,8+column)-data_sim_ff(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ff(1+row,8+column);
%                yaxis(1+row) = data_sim_ff(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;






%simulated ssa
figure(12)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:1:40
            if row==20
                xaxis(1+row-20) = NaN;
                yaxis(1+row-20) = NaN;
            else
                xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
                yaxis(1+row-20) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row-1,2+column))/(data_sim_ssa(1+row,8+column)-data_sim_ssa(1+row-1,8+column)) );
%                xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
%                yaxis(1+row-20) = data_sim_ssa(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
%    for column=21*start:21*interval:21*20
    column=21*line3;
        for row=20:-1:0
            if row==20
                xaxis(1+row) = NaN;
                yaxis(1+row) = NaN;
            else
                xaxis(1+row) = data_sim_ssa(1+row,8+column);
                yaxis(1+row) = log10( (data_sim_ssa(1+row,2+column)-data_sim_ssa(1+row+1,2+column))/(data_sim_ssa(1+row,8+column)-data_sim_ssa(1+row+1,8+column)) );
%                xaxis(1+row) = data_sim_ssa(1+row,8+column);
%                yaxis(1+row) = data_sim_ssa(1+row,5+column);
            end
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;




xlabel('V_{GS}');
ylabel('log_{10} g_{m} [S]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title([die,' ',device,', ','V_{GS} - g_{m}, ','V_{DS}=0.4V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title([die,' ',device,', ','V_{GS} - g_{m}, ','V_{DS}=-0.4V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




%##########################################################################
%######################    SUBVT PLOTS    #################################
%##########################################################################

%DENNE M FIKSES SLIK AT DEN FR TIL  BRUKE MATLAB-FUNKSJONEN SEMILOGY P
%RIKTIG VIS!!!


%#####################
%##### Vds=0.1V ######
%#####################

%measured
figure(13)
hold on
column=0;
    for row=0:1:30
        xaxis(1+row) = data_subvt(1+row,3+column);
        yaxis(1+row) = log10( abs( data_subvt(1+row,1+column) ) );
    end
    semilogy(xaxis,yaxis,'k-');
clear xaxis;
clear yaxis;






%simulated tt
figure(13)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*2;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_tt(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_tt(1+row,2+column));
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*2;
        for row=30:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_tt(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;






%simulated ss
figure(13)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*2;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_ss(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_ss(1+row,2+column));
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*2;
        for row=30:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ss(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;





%simulated ff
figure(13)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*2;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_ff(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_ff(1+row,2+column));
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*2;
        for row=30:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ff(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;






%simulated ssa
figure(13)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*2;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_ssa(1+row,2+column));
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*2;
        for row=30:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ssa(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;





xlabel('V_{GS} [V]');
ylabel('log_{10} I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title(['Subvt',', ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=0.1V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0.5]);
    title(['Subvt',', ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-0.1V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;






%#####################
%##### Vds=0.5V ######
%#####################

%measured
figure(14)
hold on
column=5;
    for row=0:1:30
        xaxis(1+row) = data_subvt(1+row,3+column);
        yaxis(1+row) = log10( abs( data_subvt(1+row,1+column) ) );
    end
    semilogy(xaxis,yaxis,'k-');
clear xaxis;
clear yaxis;





%simulated tt
figure(14)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*10;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_tt(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_tt(1+row,2+column));
        end
        plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*10;
        for row=30:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_tt(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;






%simulated ss
figure(14)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*10;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_ss(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_ss(1+row,2+column));
        end
        plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*10;
        for row=30:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ss(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;





%simulated ff
figure(14)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*10;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_ff(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_ff(1+row,2+column));
        end
        plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*10;
        for row=30:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ff(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;






%simulated ssa
figure(14)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=21*10;
        for row=10:1:40
            xaxis(1+row-10) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-10) = log10(data_sim_ssa(1+row,2+column));
        end
        plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=21*10;
        for row=30:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ssa(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;





xlabel('V_{GS} [V]');
ylabel('log_{10} I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title(['Subvt',', ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=0.5V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0.5]);
    title(['Subvt',', ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-0.5V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;






%##########################################################################
%######################  GATELEAK PLOTS   #################################
%##########################################################################

%###########
%##THIS IS USED IF VGS IS SWEPT FROM 0V TO 1V##
%###########
if ( strcmp(die,'die1') | strcmp(die,'die2') ) %This if-sentence is necessary  to determine the length of gateleak-data, since die1- and die2-data only includes Vgs sweep from 0V to 1V

%measured

figure(15)
hold on
for row=0:1:20
    xaxis(1+row) = data_gateleak(1+row,2);
    if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for each specific device
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((1.2*0.1)/(6.32)) ));
    elseif ( strcmp(device,'nmos1') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((1.0*0.2)/(6.32)) ));
    elseif ( strcmp(device,'nmos2') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((4.0*0.5)/(6.32)) ));
    elseif ( strcmp(device,'nmos3') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((4.0*1.0)/(6.32)) ));
    elseif ( strcmp(device,'pmos0') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((3.0*0.1)/(12.5)) ));
    elseif ( strcmp(device,'pmos1') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((1.0*0.2)/(12.5)) ));
    elseif ( strcmp(device,'pmos2') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((8.0*0.5)/(12.5)) ));
    elseif ( strcmp(device,'pmos3') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((8.0*1.0)/(12.5)) ));
    end
end
plot(xaxis,yaxis,'k-')
clear xaxis;
clear yaxis;






%simulated tt
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=20:1:40
        xaxis(1+row-20) = data_sim_tt(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for each specific device
            yaxis(1+row-20) = log10( abs( -(data_sim_tt(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row-20) = log10( abs( -(data_sim_tt(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row-20) = log10( abs( -(data_sim_tt(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row-20) = log10( abs( -(data_sim_tt(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=20:-1:0
        xaxis(1+row) = data_sim_tt(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;







%simulated ss
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=20:1:40
        xaxis(1+row-20) = data_sim_ss(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for specific device
            yaxis(1+row-20) = log10( abs( -(data_sim_ss(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ss(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ss(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ss(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=20:-1:0
        xaxis(1+row) = data_sim_ss(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;





%simulated ff
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=20:1:40
        xaxis(1+row-20) = data_sim_ff(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for specific device
            yaxis(1+row-20) = log10( abs( -(data_sim_ff(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ff(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ff(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ff(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=20:-1:0
        xaxis(1+row) = data_sim_ff(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;





%simulated ssa
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=20:1:40
        xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for specific device
            yaxis(1+row-20) = log10( abs( -(data_sim_ssa(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ssa(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ssa(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row-20) = log10( abs( -(data_sim_ssa(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=20:-1:0
        xaxis(1+row) = data_sim_ssa(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;




xlabel('V_{GS} [V]');
ylabel('log_{10} I_{G} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title(['Gateleak, ',die,' ',device,', ','V_{GS} - I_{G}, ','V_{DS} = 0V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title(['Gateleak, ',die,' ',device,', ','V_{GS} - I_{G}, ','V_{DS} = 0V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;













%###########
%##THIS IS USED IF VGS IS SWEPT FROM -1V TO 1V##
%###########
elseif ( strcmp(die,'die5') | strcmp(die,'die2') ) % while die5-data sweep Vgs from -1V to 1V


%measured
figure(15)
hold on
for row=0:1:40
    xaxis(1+row) = data_gateleak(1+row,2);
    if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for each specific device
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((1.2*0.1)/(6.32)) ));
    elseif ( strcmp(device,'nmos1') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((1.0*0.2)/(6.32)) ));
    elseif ( strcmp(device,'nmos2') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((4.0*0.5)/(6.32)) ));
    elseif ( strcmp(device,'nmos3') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((4.0*1.0)/(6.32)) ));
    elseif ( strcmp(device,'pmos0') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((3.0*0.1)/(12.5)) ));
    elseif ( strcmp(device,'pmos1') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((1.0*0.2)/(12.5)) ));
    elseif ( strcmp(device,'pmos2') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((8.0*0.5)/(12.5)) ));
    elseif ( strcmp(device,'pmos3') )
        yaxis(1+row) = log10( abs( data_gateleak(1+row,1)*((8.0*1.0)/(12.5)) ));
    end
end
plot(xaxis,yaxis,'k-')
clear xaxis;
clear yaxis;





%simulated tt
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=0:1:40
        xaxis(1+row) = data_sim_tt(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for each specific device
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k:')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=40:-1:0
        xaxis(1+row) = data_sim_tt(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_tt(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k:')
end
clear xaxis;
clear yaxis;







%simulated ss
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=0:1:40
        xaxis(1+row) = data_sim_ss(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for specific device
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k-.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=40:-1:0
        xaxis(1+row) = data_sim_ss(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ss(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k-.')
end
clear xaxis;
clear yaxis;





%simulated ff
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=0:1:40
        xaxis(1+row) = data_sim_ff(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for specific device
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k--')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=40:-1:0
        xaxis(1+row) = data_sim_ff(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ff(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k--')
end
clear xaxis;
clear yaxis;





%simulated ssa
figure(15)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    column=0;
    for row=0:1:40
        xaxis(1+row) = data_sim_ssa(1+row,8+column);
        if ( strcmp(device,'nmos0') ) % these if-sentences are necessary to _calculate_ gate leakage for specific device
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((1.2*0.1)/(6.32)) ));
        elseif ( strcmp(device,'nmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((1.0*0.2)/(6.32)) ));
        elseif ( strcmp(device,'nmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((4.0*0.5)/(6.32)) ));
        elseif ( strcmp(device,'nmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((4.0*1.0)/(6.32)) ));
        end
    end
    plot(xaxis,yaxis,'k.')
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    column=0;
    for row=40:-1:0
        xaxis(1+row) = data_sim_ssa(1+row,8+column);
        if ( strcmp(device,'pmos0') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((3.0*0.1)/(12.5)) ));
        elseif ( strcmp(device,'pmos1') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((1.0*0.2)/(12.5)) ));
        elseif ( strcmp(device,'pmos2') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((8.0*0.5)/(12.5)) ));
        elseif ( strcmp(device,'pmos3') )
            yaxis(1+row) = log10( abs( -(data_sim_ssa(1+row,4+column))*((8.0*1.0)/(12.5)) ));
        end
    end
    plot(xaxis,yaxis,'k.')
end
clear xaxis;
clear yaxis;




xlabel('V_{GS} [V]');
ylabel('log_{10} I_{G} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title(['Gateleak, ',die,' ',device,', ','V_{GS} - I_{G}, ','V_{DS} = 0V, ','V_{SB} = 0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 1]);
    title(['Gateleak, ',die,' ',device,', ','V_{GS} - I_{G}, ','V_{DS} = 0V, ','V_{SB} = 0V'])
end
hold off
clear xaxis;
clear yaxis;




end %ends the outer if-lines which checks the length of gateleak-data



%##########################################################################
%######################    BODY-EFFECT    #################################
%##########################################################################

%DENNE M FIKSES SLIK AT DEN FR TIL  BRUKE MATLAB-FUNKSJONEN SEMILOGY P
%RIKTIG VIS!!!


%#####################
%##### Vsb=0.0V ######
%#####################


%measured
figure(16)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=0:1:20
    for row=10
        for column=0:5:100
            xaxis0(1+column/5) = data_fine0(1+row,5+column);
            yaxis0(1+column/5) = log10( abs( data_fine0(1+row,3+column) ) );
        end
        plot(xaxis0,yaxis0,'k-')
    end
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=0:1:20
    for row=10
        for column=0:5:100
            xaxis0(1+column/5) = data_fine0(1+row,3+column);
            yaxis0(1+column/5) = log10( abs( data_fine0(1+row,1+column) ) );
        end
        plot(xaxis0,yaxis0,'k-')
    end
end
hold off
clear xaxis0;
clear yaxis0;






%simulated tt
figure(16)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*10:21:21*10
        for row=20:1:40
            xaxis(1+row-20) = data_sim_tt(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_tt(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k:')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*10:21:21*10
        for row=20:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_tt(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k:')
    end
end
hold off
clear xaxis;
clear yaxis;






%simulated ss
figure(16)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*10:21:21*10
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ss(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_ss(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k-.')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*10:21:21*10
        for row=20:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ss(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k-.')
    end
end
hold off
clear xaxis;
clear yaxis;







%simulated ff
figure(16)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*10:21:21*10
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ff(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_ff(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k--')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*10:21:21*10
        for row=20:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ff(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k--')
    end
end
hold off
clear xaxis;
clear yaxis;





%simulated ssa
figure(16)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*10:21:21*10
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_ssa(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k.')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*10:21:21*10
        for row=20:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ssa(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k.')
    end
end
hold off
clear xaxis;
clear yaxis;







xlabel('V_{GS} [V]');
ylabel('log_{10} I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title(['Body effect, ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=0.5V, ','V_{SB}=0.0V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title(['Body effect, ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-0.5, ','V_{SB}=0.0V'])
end
hold off
clear xaxis;
clear yaxis;











%#####################
%##### Vsb=0.2V ######
%#####################


%measured
figure(17)
hold on
if ( (strcmp(die,'die1') & strcmp(device,'nmos0')) | (strcmp(die,'die1') & strcmp(device,'nmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos0')) | (strcmp(die,'die2') & strcmp(device,'nmos1')) | (strcmp(die,'die2') & strcmp(device,'nmos2')) | (strcmp(die,'die2') & strcmp(device,'pmos0')) | (strcmp(die,'die2') & strcmp(device,'pmos3')) | (strcmp(die,'die5') & strcmp(device,'nmos1')) | (strcmp(die,'die5') & strcmp(device,'nmos2')) | (strcmp(die,'die5') & strcmp(device,'pmos0')) | (strcmp(die,'die5') & strcmp(device,'pmos1')) | (strcmp(die,'die5') & strcmp(device,'pmos2')) )
%    for row=0:1:20
    for row=10
        for column=0:5:100
            xaxis(1+column/5) = data_fine2(1+row,5+column);
            yaxis(1+column/5) = log10( abs( data_fine2(1+row,3+column) ) );
        end
        plot(xaxis,yaxis,'k-')
    end
elseif ( (strcmp(die,'die1') & strcmp(device,'nmos2')) | (strcmp(die,'die1') & strcmp(device,'nmos3')) | (strcmp(die,'die1') & strcmp(device,'pmos1')) | (strcmp(die,'die1') & strcmp(device,'pmos2')) | (strcmp(die,'die1') & strcmp(device,'pmos3')) | (strcmp(die,'die2') & strcmp(device,'nmos3')) | (strcmp(die,'die2') & strcmp(device,'pmos1')) | (strcmp(die,'die2') & strcmp(device,'pmos2')) | (strcmp(die,'die5') & strcmp(device,'nmos0')) | (strcmp(die,'die5') & strcmp(device,'nmos3')) | (strcmp(die,'die5') & strcmp(device,'pmos3')) )
%    for row=0:1:20
    for row=10
        for column=0:5:100
            xaxis(1+column/5) = data_fine2(1+row,3+column);
            yaxis(1+column/5) = log10( abs( data_fine2(1+row,1+column) ) );
        end
        plot(xaxis,yaxis,'k-')
    end
end
hold off
clear xaxis;
clear yaxis;






%simulated tt
figure(17)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:1:40
            xaxis(1+row-20) = data_sim_tt(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_tt(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k:')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:-1:0
            xaxis(1+row) = data_sim_tt(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_tt(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k:')
    end
end
hold off
clear xaxis;
clear yaxis;






%simulated ss
figure(17)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ss(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_ss(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k-.')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:-1:0
            xaxis(1+row) = data_sim_ss(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ss(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k-.')
    end
end
hold off
clear xaxis;
clear yaxis;







%simulated ff
figure(17)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ff(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_ff(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k--')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:-1:0
            xaxis(1+row) = data_sim_ff(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ff(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k--')
    end
end
hold off
clear xaxis;
clear yaxis;






%simulated ssa
figure(17)
hold on
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:1:40
            xaxis(1+row-20) = data_sim_ssa(1+row,8+column);
            yaxis(1+row-20) = log10( abs( data_sim_ssa(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k.')
    end
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    for column=21*(42+10):21:21*(42+10)
        for row=20:-1:0
            xaxis(1+row) = data_sim_ssa(1+row,8+column);
            yaxis(1+row) = log10( abs( data_sim_ssa(1+row,2+column) ) );
        end
        plot(xaxis,yaxis,'k.')
    end
end
hold off
clear xaxis;
clear yaxis;







xlabel('V_{GS} [V]');
ylabel('log_{10} I_{D} [A]');
if ( strcmp(device,'nmos0') | strcmp(device,'nmos1') | strcmp(device,'nmos2') | strcmp(device,'nmos3') )
    title(['Body effect, ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=0.5V, ','V_{SB}=0.2V'])
elseif ( strcmp(device,'pmos0') | strcmp(device,'pmos1') | strcmp(device,'pmos2') | strcmp(device,'pmos3') )
    xlim('manual');
    xlim([-1 0]);
    title(['Body effect, ',die,' ',device,', ','V_{GS} - I_{D}, ','V_{DS}=-0.5, ','V_{SB}=-0.2V'])
end
hold off
clear xaxis;
clear yaxis;






